==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;SolydXK&apos;yı seçtiğiniz için teşekkür ederiz&lt;/h3&gt;&lt;br /&gt;Seçtiğiniz Linux dağıtımının özellikleri:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Güvenli ve kararlı&lt;/li&gt;&lt;li&gt;Hızlı ve esnek&lt;/li&gt;&lt;li&gt;Masaüstü kullanımına hazır&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Bu yeni sürümün tadını çıkartın ve SolydXK&apos;yı seçtiğiniz için teşekkür ederiz.&lt;br /&gt;&lt;br /&gt;Kurulum ayarlarınıza bağlı olarak 15-30 dakika alacak.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Devlerin omuzları üzerinde duruyor&lt;/h3&gt;&lt;br /&gt;SolydXK, Debian tabanlı bir GNU/Linux dağıtımıdır ve Debian ile uyumludur.&lt;br /&gt;&lt;br /&gt;SolydXK; SolydX için hafif bir masaüstü olan Xfce&apos;yi, SolydK için yüksek yapılandırılabilir ve ilgi çekici masaüstü olan KDE&apos;yi kullanır.&lt;br /&gt;&lt;br /&gt;Yeniliklerimiz, Debian&apos;ın hızlı geliştirilmesi ve devasa Debian paket seçimi SolydXK&apos;yı ev kullanıcılarının kullanabileceği en çekici masaüstü işletim sistemlerinden biri haline getiriyor.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Kullanıma hazır&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird ve LibreOffice SolydXK ile önyüklü olarak gelir, böylece masaüstü ve interneti hızlıca kullanmaya başlayabilirsiniz.&lt;br /&gt;&lt;br /&gt;Diğer bir çok Linux dağıtımlarından farklı olarak, SolydXK müziklerinizi, internet videolarınızı ve daha fazlasını oynatmaya hazır olrak gelir.&lt;br /&gt;&lt;br /&gt;Bir fare tıklamasıyla pek çok yazılım kurulabilir.&lt;br /&gt;&lt;br /&gt;SolydXK çok kullanılan dosya biçimleri ile uyumludur, örneğin: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg ve daha fazlası.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;SolydXK&apos;yı yükler yüklemez ofis araçlarını kullanıma hazır bulursunuz&lt;/h3&gt;&lt;br /&gt;LibreOffice,  güçlü bir ofis yazılım paketidir, SolydXK ile kurulu gelir.&lt;br /&gt;&lt;br /&gt;LibreOffice öğrenmesi ve kullanması çok kolaydır.&lt;br /&gt;&lt;br /&gt;Bunu yazı yazmak, sunum ve tablolar hazırlamanın yanı diyagramlar ve veri tabanları oluşturmak için kullanabilirsiniz.&lt;br /&gt;&lt;br /&gt;LibreOffice standart OpenDocument biçimini kullanır ve WordPerfect ve Microsoft Office gibi diğer çok kullanılan ofis uygulamalarının belgeleriyle de çalışır.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Önde gelen işletim sistemlerine bir alternatif&lt;/h3&gt;&lt;br /&gt;SolydXK kolay kullanımlı, güçlü ve yapılandırılabilir bir dağıtımdır.&lt;br /&gt;&lt;br /&gt;SolydXK güvenli ve kararlıdır. - Linux dağıtımları dışındaki - Diğer işletim sistemlerinin aksine, virus ve casus yazılımlara eğilimli değildir, disk parçalanması gibi olumsuzluklar yaşamayacağınız gibi periyodik temizlik gerektiren kayıt defterine de sahip değildir.&lt;br /&gt;&lt;br /&gt;SolydXK diğer işletim sistemlerini algılayabilir ve bunların yanına kendiliğinden yüklenebilir. Bilgisayarı başlatırken hangi işletim sistemi ile açılış yapacağınızı seçebilirsiniz.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Güvenli güncelleştirmeler&lt;/h3&gt;&lt;br /&gt;Bazı işletim sistemleri sisteminizi gerçekten olması gerekenden daha zor hale getirmektedir. SolydXK, yükseltmelerin hızlı ve kolay olması gerektiğini düşünüyor ve ardından yoldan çekiliyor.&lt;br /&gt;&lt;br /&gt;Güncelleme Yöneticisi sistem tepsinizde ihtiyatlı bir şekilde oturur ve güncelleştirmelerin ne zaman kullanılabilir olduğunu size bildirir. İstemediğiniz zaman güncelleştirmeleri uygulamanız gerekmez. Güncelleme Yöneticisi hiçbir şekilde ortaya çıkamaz veya sizi rahatsız etmez.&lt;br /&gt;&lt;br /&gt;Tüm güncelleştirilen dosyalar güvenilir geliştiriciler ve bakımcılar tarafından korunur ve yakından denetlenir.&lt;br /&gt;&lt;br /&gt;Tüm dosyalar kullanımınız için özel güvenli depolarda saklanır.&lt;br /&gt;&lt;br /&gt;Güvenlik depoları günlük olarak senkronize edilir.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Büyük Bir Topluluk&lt;/h3&gt;&lt;br /&gt;SolydXK kullanıcıları tutkularını ve heyecanlarını paylaşmaktan mutluluk duyarlar ve yardım etmeye istekliler. Forumlarda soru sormaktan veya topluluğa katılmaktan çekinmeyin.&lt;br /&gt;&lt;br /&gt;Bize geri bildirimde bulunun ve deneyimlerinizi anlatın. Fikirlerinizi dinleyip bunları SolydXK&apos;nın daha iyileştirilmesi için kullanacağız.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;SolydXK&apos;yı seçtiğiniz için teşekkür ederiz&lt;/h3&gt;&lt;br /&gt;Seçtiğiniz Linux dağıtımının özellikleri:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Güvenli ve kararlı&lt;/li&gt;&lt;li&gt;Hızlı ve esnek&lt;/li&gt;&lt;li&gt;Masaüstü kullanımına hazır&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Bu yeni sürümün tadını çıkartın ve SolydXK&apos;yı seçtiğiniz için teşekkür ederiz.&lt;br /&gt;&lt;br /&gt;Kurulum ayarlarınıza bağlı olarak 15-30 dakika alacak.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Devlerin omuzları üzerinde duruyor&lt;/h3&gt;&lt;br /&gt;SolydXK, Debian tabanlı bir GNU/Linux dağıtımıdır ve Debian ile uyumludur.&lt;br /&gt;&lt;br /&gt;SolydXK; SolydX için hafif bir masaüstü olan Xfce&apos;yi, SolydK için yüksek yapılandırılabilir ve ilgi çekici masaüstü olan KDE&apos;yi kullanır.&lt;br /&gt;&lt;br /&gt;Yeniliklerimiz, Debian&apos;ın hızlı geliştirilmesi ve devasa Debian paket seçimi SolydXK&apos;yı ev kullanıcılarının kullanabileceği en çekici masaüstü işletim sistemlerinden biri haline getiriyor.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Kullanıma hazır&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird ve LibreOffice SolydXK ile önyüklü olarak gelir, böylece masaüstü ve interneti hızlıca kullanmaya başlayabilirsiniz.&lt;br /&gt;&lt;br /&gt;Diğer bir çok Linux dağıtımlarından farklı olarak, SolydXK müziklerinizi, internet videolarınızı ve daha fazlasını oynatmaya hazır olrak gelir.&lt;br /&gt;&lt;br /&gt;Bir fare tıklamasıyla pek çok yazılım kurulabilir.&lt;br /&gt;&lt;br /&gt;SolydXK çok kullanılan dosya biçimleri ile uyumludur, örneğin: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg ve daha fazlası.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;SolydXK&apos;yı yükler yüklemez ofis araçlarını kullanıma hazır bulursunuz&lt;/h3&gt;&lt;br /&gt;LibreOffice,  güçlü bir ofis yazılım paketidir, SolydXK ile kurulu gelir.&lt;br /&gt;&lt;br /&gt;LibreOffice öğrenmesi ve kullanması çok kolaydır.&lt;br /&gt;&lt;br /&gt;Bunu yazı yazmak, sunum ve tablolar hazırlamanın yanı diyagramlar ve veri tabanları oluşturmak için kullanabilirsiniz.&lt;br /&gt;&lt;br /&gt;LibreOffice standart OpenDocument biçimini kullanır ve WordPerfect ve Microsoft Office gibi diğer çok kullanılan ofis uygulamalarının belgeleriyle de çalışır.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Önde gelen işletim sistemlerine bir alternatif&lt;/h3&gt;&lt;br /&gt;SolydXK kolay kullanımlı, güçlü ve yapılandırılabilir bir dağıtımdır.&lt;br /&gt;&lt;br /&gt;SolydXK güvenli ve kararlıdır. - Linux dağıtımları dışındaki - Diğer işletim sistemlerinin aksine, virus ve casus yazılımlara eğilimli değildir, disk parçalanması gibi olumsuzluklar yaşamayacağınız gibi periyodik temizlik gerektiren kayıt defterine de sahip değildir.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Güvenli güncelleştirmeler&lt;/h3&gt;&lt;br /&gt;Bazı işletim sistemleri sisteminizi gerçekten olması gerekenden daha zor hale getirmektedir. SolydXK, yükseltmelerin hızlı ve kolay olması gerektiğini düşünüyor ve ardından yoldan çekiliyor.&lt;br /&gt;&lt;br /&gt;Güncelleme Yöneticisi sistem tepsinizde ihtiyatlı bir şekilde oturur ve güncelleştirmelerin ne zaman kullanılabilir olduğunu size bildirir. İstemediğiniz zaman güncelleştirmeleri uygulamanız gerekmez. Güncelleme Yöneticisi hiçbir şekilde ortaya çıkamaz veya sizi rahatsız etmez.&lt;br /&gt;&lt;br /&gt;Tüm güncelleştirilen dosyalar güvenilir geliştiriciler ve bakımcılar tarafından korunur ve yakından denetlenir.&lt;br /&gt;&lt;br /&gt;Tüm dosyalar kullanımınız için özel güvenli depolarda saklanır.&lt;br /&gt;&lt;br /&gt;Güvenlik depoları günlük olarak senkronize edilir.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Büyük Bir Topluluk&lt;/h3&gt;&lt;br /&gt;SolydXK kullanıcıları tutkularını ve heyecanlarını paylaşmaktan mutluluk duyarlar ve yardım etmeye istekliler. Forumlarda soru sormaktan veya topluluğa katılmaktan çekinmeyin.&lt;br /&gt;&lt;br /&gt;Bize geri bildirimde bulunun ve deneyimlerinizi anlatın. Fikirlerinizi dinleyip bunları SolydXK&apos;nın daha iyileştirilmesi için kullanacağız.</translation>
    </message>
</context>
</TS>
